@@ -1,21 +1,9 @@
-//
-// Copyright (C) 2016~2016 by CSSlayer
-// wengxt@gmail.com
-//
-// This library is free software; you can redistribute it and/or modify
-// it under the terms of the GNU Lesser General Public License as
-// published by the Free Software Foundation; either version 2.1 of the
-// License, or (at your option) any later version.
-//
-// This library is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-// Lesser General Public License for more details.
-//
-// You should have received a copy of the GNU Lesser General Public
-// License along with this library; see the file COPYING. If not,
-// see <http://www.gnu.org/licenses/>.
-//
+/*
+ * SPDX-FileCopyrightText: 2016-2016 CSSlayer <wengxt@gmail.com>
+ *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
+ *
+ */
 #ifndef _FCITX_TEXT_H_
 #define _FCITX_TEXT_H_
 
@@ -39,7 +27,7 @@ class FCITXCORE_EXPORT Text {
 public:
     Text();
     explicit Text(const std::string &text,
-                  TextFormatFlags flag = TextFormatFlag::None);
+                  TextFormatFlags flag = TextFormatFlag::NoFlag);
     FCITX_DECLARE_VIRTUAL_DTOR_COPY_AND_MOVE(Text);
 
     /// Get cursor by byte.
@@ -48,7 +36,7 @@ public:
     void setCursor(int pos = -1);
     void clear();
     void append(const std::string &str,
-                TextFormatFlags flag = TextFormatFlag::None);
+                TextFormatFlags flag = TextFormatFlag::NoFlag);
     const std::string &stringAt(int idx) const;
     TextFormatFlags formatAt(int idx) const;
     size_t size() const;
